@@ -29,35 +29,38 @@
 
 namespace NetworKit {
 
+struct Edge {
+    node u, v;
+
+    Edge() : u(none), v(none) {}
+
+    Edge(node _u, node _v, bool sorted = false) {
+        u = sorted ? std::min(_u, _v) : _u;
+        v = sorted ? std::max(_u, _v) : _v;
+    }
+};
+
 /**
  * A weighted edge used for the graph constructor with
  * initializer list syntax.
  */
-struct WeightedEdge {
-    node u, v;
+struct WeightedEdge : Edge {
     edgeweight weight;
 
-    WeightedEdge(node u, node v, edgeweight w) : u(u), v(v), weight(w) {}
-};
-inline bool operator<(const WeightedEdge &e1, const WeightedEdge &e2) {
-    return e1.weight < e2.weight;
-}
-struct Edge {
-    node u, v;
+    // Needed by cython
+    WeightedEdge() : Edge(), weight(std::numeric_limits<edgeweight>::max()) {}
 
-    Edge(node _u, node _v, bool sorted = false) {
-        if (sorted) {
-            u = std::min(_u, _v);
-            v = std::max(_u, _v);
-        } else {
-            u = _u;
-            v = _v;
-        }
-    }
+    WeightedEdge(node u, node v, edgeweight w) : Edge(u, v), weight(w) {}
 };
+
 inline bool operator==(const Edge &e1, const Edge &e2) {
     return e1.u == e2.u && e1.v == e2.v;
 }
+
+inline bool operator<(const WeightedEdge &e1, const WeightedEdge &e2) {
+    return e1.weight < e2.weight;
+}
+
 struct Unsafe {};
 static constexpr Unsafe unsafe{};
 } // namespace NetworKit
@@ -419,11 +422,369 @@ private:
     }
 
 public:
+    /**
+     * Class to iterate over the nodes of a graph.
+     */
+    class NodeIterator {
+
+        const Graph *G;
+        node u;
+
+    public:
+        // The value type of the nodes (i.e. nodes). Returned by
+        // operator*().
+        using value_type = node;
+
+        // Reference to the value_type, required by STL.
+        using reference = value_type &;
+
+        // Pointer to the value_type, required by STL.
+        using pointer = value_type *;
+
+        // STL iterator category.
+        using iterator_category = std::forward_iterator_tag;
+
+        // Signed integer type of the result of subtracting two pointers,
+        // required by STL.
+        using difference_type = ptrdiff_t;
+
+        // Own type.
+        using self = NodeIterator;
+
+        NodeIterator(const Graph *G, node u) : G(G), u(u) {
+            if (!G->hasNode(u) && u < G->upperNodeIdBound()) {
+                ++(*this);
+            }
+        }
+
+        /**
+         * @brief WARNING: This constructor is required for Python and should not be used as the
+         * iterator is not initialized.
+         */
+        NodeIterator() : G(nullptr) {}
+
+        ~NodeIterator() = default;
+
+        NodeIterator operator++() {
+            assert(u < G->upperNodeIdBound());
+            do {
+                ++u;
+            } while (!(G->hasNode(u) || u >= G->upperNodeIdBound()));
+            return *this;
+        }
+
+        NodeIterator operator++(int) {
+            const auto tmp = *this;
+            ++(*this);
+            return tmp;
+        }
+
+        NodeIterator operator--() {
+            assert(u);
+            do {
+                --u;
+            } while (!G->hasNode(u));
+            return *this;
+        }
+
+        NodeIterator operator--(int) {
+            const auto tmp = *this;
+            --(*this);
+            return tmp;
+        }
+
+        bool operator==(const NodeIterator &rhs) const noexcept { return u == rhs.u; }
+
+        bool operator!=(const NodeIterator &rhs) const noexcept { return !(*this == rhs); }
+
+        node operator*() const noexcept {
+            assert(u < G->upperNodeIdBound());
+            return u;
+        }
+    };
+
+    /**
+     * Wrapper class to iterate over a range of the nodes of a graph.
+     */
+    class NodeRange {
+
+        const Graph *G;
+
+    public:
+        NodeRange(const Graph &G) : G(&G) {}
+
+        NodeRange() : G(nullptr){};
+
+        ~NodeRange() = default;
+
+        NodeIterator begin() const noexcept {
+            assert(G);
+            return NodeIterator(G, node{0});
+        }
+
+        NodeIterator end() const noexcept {
+            assert(G);
+            return NodeIterator(G, G->upperNodeIdBound());
+        }
+    };
+
+    // Necessary for friendship with EdgeIteratorBase.
+    class EdgeIterator;
+    class EdgeWeightIterator;
+
+    class EdgeIteratorBase {
+        friend class EdgeIterator;
+        friend class EdgeWeightIterator;
+
+        const Graph *G;
+        NodeIterator nodeIter;
+        index i;
+
+        bool validEdge() const noexcept {
+            return G->isDirected() || (*nodeIter <= G->outEdges[*nodeIter][i]);
+        }
+
+        void nextEdge() {
+            do {
+                if (++i >= G->degree(*nodeIter)) {
+                    i = 0;
+                    do {
+                        assert(nodeIter != G->nodeRange().end());
+                        ++nodeIter;
+                        if (nodeIter == G->nodeRange().end()) {
+                            return;
+                        }
+                    } while (!G->degree(*nodeIter));
+                }
+            } while (!validEdge());
+        }
+
+        void prevEdge() {
+            do {
+                if (!i) {
+                    do {
+                        assert(nodeIter != G->nodeRange().begin());
+                        --nodeIter;
+                    } while (!G->degree(*nodeIter));
+
+                    i = G->degree(*nodeIter);
+                }
+                --i;
+            } while (!validEdge());
+        }
+
+        EdgeIteratorBase(const Graph *G, NodeIterator nodeIter)
+            : G(G), nodeIter(nodeIter), i(index{0}) {
+            if (nodeIter != G->nodeRange().end() && !G->degree(*nodeIter)) {
+                nextEdge();
+            }
+        }
+
+        /**
+         * @brief WARNING: This constructor is required for Python and should not be used as the
+         * iterator is not initialized.
+         */
+        EdgeIteratorBase() : G(nullptr) {}
+
+        virtual ~EdgeIteratorBase() = default;
+
+        bool operator==(const EdgeIteratorBase &rhs) const noexcept {
+            return nodeIter == rhs.nodeIter && i == rhs.i;
+        }
+
+        bool operator!=(const EdgeIteratorBase &rhs) const noexcept { return !(*this == rhs); }
+    };
+
+    /**
+     * Class to iterate over the edges of the graph. If the graph is undirected, operator*()
+     * returns the edges (u, v) s.t. u <= v.
+     */
+    class EdgeIterator : public EdgeIteratorBase {
+
+    public:
+        // The value type of the edges (i.e. a pair). Returned by operator*().
+        using value_type = Edge;
+
+        // Reference to the value_type, required by STL.
+        using reference = value_type &;
+
+        // Pointer to the value_type, required by STL.
+        using pointer = value_type *;
+
+        // STL iterator category.
+        using iterator_category = std::forward_iterator_tag;
+
+        // Signed integer type of the result of subtracting two pointers,
+        // required by STL.
+        using difference_type = ptrdiff_t;
+
+        // Own type.
+        using self = EdgeIterator;
+
+        EdgeIterator(const Graph *G, NodeIterator nodeIter) : EdgeIteratorBase(G, nodeIter) {}
+
+        EdgeIterator() : EdgeIteratorBase() {}
+
+        bool operator==(const EdgeIterator &rhs) const noexcept {
+            return this->EdgeIteratorBase::operator==(static_cast<EdgeIteratorBase>(rhs));
+        }
+
+        bool operator!=(const EdgeIterator &rhs) const noexcept { return !(*this == rhs); }
+
+        Edge operator*() const noexcept {
+            assert(nodeIter != G->nodeRange().end());
+            return Edge(*nodeIter, G->outEdges[*nodeIter][i]);
+        }
+
+        EdgeIterator operator++() {
+            nextEdge();
+            return *this;
+        }
+
+        EdgeIterator operator++(int) {
+            const auto tmp = *this;
+            ++(*this);
+            return tmp;
+        }
+
+        EdgeIterator operator--() {
+            prevEdge();
+            return *this;
+        }
+
+        EdgeIterator operator--(int) {
+            const auto tmp = *this;
+            --(*this);
+            return tmp;
+        }
+    };
+
+    /**
+     * Class to iterate over the edges of the graph and their weights. If the graph is undirected,
+     * operator*() returns a WeightedEdge struct with u <= v.
+     */
+    class EdgeWeightIterator : public EdgeIteratorBase {
+    public:
+        // The value type of the edges and their weights (i.e. WeightedEdge). Returned by
+        // operator*().
+        using value_type = WeightedEdge;
+
+        // Reference to the value_type, required by STL.
+        using reference = value_type &;
+
+        // Pointer to the value_type, required by STL.
+        using pointer = value_type *;
+
+        // STL iterator category.
+        using iterator_category = std::forward_iterator_tag;
+
+        // Signed integer type of the result of subtracting two pointers,
+        // required by STL.
+        using difference_type = ptrdiff_t;
+
+        // Own type.
+        using self = EdgeWeightIterator;
+
+        EdgeWeightIterator(const Graph *G, NodeIterator nodeIter) : EdgeIteratorBase(G, nodeIter) {}
+
+        /**
+         * @brief WARNING: This constructor is required for Python and should not be used as the
+         * iterator is not initialized.
+         */
+        EdgeWeightIterator() : EdgeIteratorBase() {}
+
+        bool operator==(const EdgeWeightIterator &rhs) const noexcept {
+            return this->EdgeIteratorBase::operator==(static_cast<EdgeIteratorBase>(rhs));
+        }
+
+        bool operator!=(const EdgeWeightIterator &rhs) const noexcept { return !(*this == rhs); }
+
+        EdgeWeightIterator operator++() {
+            nextEdge();
+            return *this;
+        }
+
+        EdgeWeightIterator operator++(int) {
+            const auto tmp = *this;
+            ++(*this);
+            return tmp;
+        }
+
+        EdgeWeightIterator operator--() {
+            prevEdge();
+            return *this;
+        }
+
+        EdgeWeightIterator operator--(int) {
+            const auto tmp = *this;
+            --(*this);
+            return tmp;
+        }
+
+        WeightedEdge operator*() const noexcept {
+            assert(nodeIter != G->nodeRange().end());
+            return WeightedEdge(*nodeIter, G->outEdges[*nodeIter][i],
+                                G->isWeighted() ? G->outEdgeWeights[*nodeIter][i] : 1);
+        }
+    };
+
+    /**
+     * Wrapper class to iterate over a range of the edges of a graph.
+     */
+    class EdgeRange {
+
+        const Graph *G;
+
+    public:
+        EdgeRange(const Graph &G) : G(&G) {}
+
+        EdgeRange() : G(nullptr){};
+
+        ~EdgeRange() = default;
+
+        EdgeIterator begin() const {
+            assert(G);
+            return EdgeIterator(G, G->nodeRange().begin());
+        }
+
+        EdgeIterator end() const {
+            assert(G);
+            return EdgeIterator(G, G->nodeRange().end());
+        }
+    };
+
+    /**
+     * Wrapper class to iterate over a range of the edges of a graph and their weights.
+     */
+    class EdgeWeightRange {
+
+        const Graph *G;
+
+    public:
+        EdgeWeightRange(const Graph &G) : G(&G) {}
+
+        EdgeWeightRange() : G(nullptr){};
+
+        ~EdgeWeightRange() = default;
+
+        EdgeWeightIterator begin() const {
+            assert(G);
+            return EdgeWeightIterator(G, G->nodeRange().begin());
+        }
+
+        EdgeWeightIterator end() const {
+            assert(G);
+            return EdgeWeightIterator(G, G->nodeRange().end());
+        }
+    };
+
     /**
      * Class to iterate over the in/out neighbors of a node.
      */
     class NeighborIterator {
 
+        std::vector<node>::const_iterator nIter;
+
     public:
         // The value type of the neighbors (i.e. nodes). Returned by
         // operator*().
@@ -449,14 +810,14 @@ public:
 
         /**
          * @brief WARNING: This contructor is required for Python and should not be used as the
-         * iterator is not initialised.
+         * iterator is not initialized.
          */
         NeighborIterator() {}
 
         NeighborIterator operator++() {
-            auto prev = *this;
+            const auto tmp = *this;
             ++nIter;
-            return prev;
+            return tmp;
         }
 
         NeighborIterator operator++(int) {
@@ -465,9 +826,9 @@ public:
         }
 
         NeighborIterator operator--() {
-            auto prev = *this;
+            const auto tmp = *this;
             --nIter;
-            return prev;
+            return tmp;
         }
 
         NeighborIterator operator--(int) {
@@ -477,12 +838,9 @@ public:
 
         bool operator==(const NeighborIterator &rhs) const { return nIter == rhs.nIter; }
 
-        bool operator!=(const NeighborIterator &rhs) const { return nIter != rhs.nIter; }
+        bool operator!=(const NeighborIterator &rhs) const { return !(nIter == rhs.nIter); }
 
         node operator*() const { return *nIter; }
-
-    private:
-        std::vector<node>::const_iterator nIter;
     };
 
     /**
@@ -491,6 +849,9 @@ public:
      */
     class NeighborWeightIterator {
 
+        std::vector<node>::const_iterator nIter;
+        std::vector<edgeweight>::const_iterator wIter;
+
     public:
         // The value type of the neighbors (i.e. nodes). Returned by
         // operator*().
@@ -517,46 +878,38 @@ public:
             : nIter(nodesIter), wIter(weightIter) {}
 
         NeighborWeightIterator operator++() {
-            auto prev = *this;
             ++nIter;
             ++wIter;
-            return prev;
+            return *this;
         }
 
         NeighborWeightIterator operator++(int) {
-            ++nIter;
-            ++wIter;
-            return *this;
+            const auto tmp = *this;
+            ++(*this);
+            return tmp;
         }
 
         NeighborWeightIterator operator--() {
-            auto prev = *this;
-            --nIter;
-            --wIter;
-            return prev;
-        }
-
-        NeighborWeightIterator operator--(int) {
             --nIter;
             --wIter;
             return *this;
         }
 
+        NeighborWeightIterator operator--(int) {
+            const auto tmp = *this;
+            --(*this);
+            return tmp;
+        }
+
         bool operator==(const NeighborWeightIterator &rhs) const {
             return nIter == rhs.nIter && wIter == rhs.wIter;
         }
 
-        bool operator!=(const NeighborWeightIterator &rhs) const {
-            return nIter != rhs.nIter || wIter != rhs.wIter;
-        }
+        bool operator!=(const NeighborWeightIterator &rhs) const { return !(*this == rhs); }
 
         const std::pair<node, edgeweight> operator*() const {
             return std::make_pair(*nIter, *wIter);
         }
-
-    private:
-        std::vector<node>::const_iterator nIter;
-        std::vector<edgeweight>::const_iterator wIter;
     };
 
     /**
@@ -565,28 +918,25 @@ public:
      */
     template <bool InEdges = false>
     class NeighborRange {
+        const Graph *G;
+        node u;
+
     public:
         NeighborRange(const Graph &G, node u) : G(&G), u(u) { assert(G.hasNode(u)); };
 
         NeighborRange() : G(nullptr){};
 
         NeighborIterator begin() const {
-            assert(G != nullptr);
-            if (InEdges)
-                return NeighborIterator(G->inEdges[u].begin());
-            return NeighborIterator(G->outEdges[u].begin());
+            assert(G);
+            return InEdges ? NeighborIterator(G->inEdges[u].begin())
+                           : NeighborIterator(G->outEdges[u].begin());
         }
 
         NeighborIterator end() const {
-            assert(G != nullptr);
-            if (InEdges)
-                return NeighborIterator(G->inEdges[u].end());
-            return NeighborIterator(G->outEdges[u].end());
+            assert(G);
+            return InEdges ? NeighborIterator(G->inEdges[u].end())
+                           : NeighborIterator(G->outEdges[u].end());
         }
-
-    private:
-        const Graph *G;
-        node u;
     };
 
     using OutNeighborRange = NeighborRange<false>;
@@ -600,24 +950,22 @@ public:
     template <bool InEdges = false>
     class NeighborWeightRange {
 
+        const Graph &G;
+        const node u;
+
     public:
         NeighborWeightRange(const Graph &G, node u) : G(G), u(u){};
 
         NeighborWeightIterator begin() const {
-            if (InEdges)
-                return NeighborWeightIterator(G.inEdges[u].begin(), G.inEdgeWeights[u].begin());
-            return NeighborWeightIterator(G.outEdges[u].begin(), G.outEdgeWeights[u].begin());
+            return InEdges
+                       ? NeighborWeightIterator(G.inEdges[u].begin(), G.inEdgeWeights[u].begin())
+                       : NeighborWeightIterator(G.outEdges[u].begin(), G.outEdgeWeights[u].begin());
         }
 
         NeighborWeightIterator end() const {
-            if (InEdges)
-                return NeighborWeightIterator(G.inEdges[u].end(), G.inEdgeWeights[u].end());
-            return NeighborWeightIterator(G.outEdges[u].end(), G.outEdgeWeights[u].end());
+            return InEdges ? NeighborWeightIterator(G.inEdges[u].end(), G.inEdgeWeights[u].end())
+                           : NeighborWeightIterator(G.outEdges[u].end(), G.outEdgeWeights[u].end());
         }
-
-    private:
-        const Graph &G;
-        const node u;
     };
 
     /**
@@ -1348,6 +1696,27 @@ public:
      */
     std::vector<node> TLX_DEPRECATED(neighbors(node u) const);
 
+    /**
+     * Get an iterable range over the nodes of the graph.
+     *
+     * @return Iterator range over the nodes of the graph.
+     */
+    NodeRange nodeRange() const noexcept { return NodeRange(*this); }
+
+    /**
+     * Get an iterable range over the edges of the graph.
+     *
+     * @return Iterator range over the edges of the graph.
+     */
+    EdgeRange edgeRange() const noexcept { return EdgeRange(*this); }
+
+    /**
+     * Get an iterable range over the edges of the graph and their weights.
+     *
+     * @return Iterator range over the edges of the graph and their weights.
+     */
+    EdgeWeightRange edgeWeightRange() const noexcept { return EdgeWeightRange(*this); }
+
     /**
      * Get an iterable range over the neighbors of @a.
      *
@@ -1417,6 +1786,14 @@ public:
             return none;
     }
 
+    /**
+     * Get i-th (outgoing) neighbor of @a u.
+     *
+     * @param u Node.
+     * @param i index; should be in [0, degreeOut(u))
+     * @return @a i -th (outgoing) neighbor of @a u, or @c none if no such
+     * neighbor exists.
+     */
     node getIthNeighbor(node u, index i) const {
         if (!hasNode(u) || i >= outEdges[u].size())
             return none;
