@@ -7,10 +7,10 @@
 
 #include <memory>
 
-#include "../distance/BFS.h"
-#include "../distance/Dijkstra.h"
-#include "../distance/SSSP.h"
-#include "HarmonicCloseness.h"
+#include <networkit/distance/BFS.hpp>
+#include <networkit/distance/Dijkstra.hpp>
+#include <networkit/distance/SSSP.hpp>
+#include <networkit/centrality/HarmonicCloseness.hpp>
 
 namespace NetworKit {
 
