@@ -2,7 +2,7 @@
  *
  */
 
-#include "LocalCoverEvaluation.h"
+#include <networkit/community/LocalCoverEvaluation.hpp>
 
 NetworKit::LocalCoverEvaluation::LocalCoverEvaluation(const NetworKit::Graph &G, const NetworKit::Cover &C) : G(G), C(C) {
 
