@@ -5,7 +5,7 @@
 *      Author: Eugenio Angriman
 */
 
-#include "DynWeaklyConnectedComponents.h"
+#include <networkit/components/DynWeaklyConnectedComponents.hpp>
 
 namespace NetworKit {
 
@@ -139,7 +139,7 @@ namespace NetworKit {
 
 
     void DynWeaklyConnectedComponents::updateBatch(
-        const std::vector<GraphEvent>& batch
+        const std::vector<GraphEvent> &
     ) {
         run();
     }
@@ -326,7 +326,7 @@ namespace NetworKit {
         node u,
         node s,
         node w,
-        node v,
+        node,
         count d,
         std::queue<node>& q,
         bool& nextEdgeFound,
