@@ -5,7 +5,7 @@
  *      Author: cls
  */
 
-#include "GraphEventHandler.h"
+#include <networkit/dynamics/GraphEventHandler.hpp>
 
 namespace NetworKit {
 
