@@ -5,9 +5,11 @@
  *      Author: Kolja Esders (kolja.esders@student.kit.edu)
  */
 
-#include "LinkThresholder.h"
-#include "PredictionsSorter.h"
-#include "../auxiliary/Parallel.h"
+#include <list>
+
+#include <networkit/linkprediction/LinkThresholder.hpp>
+#include <networkit/linkprediction/PredictionsSorter.hpp>
+#include <networkit/auxiliary/Parallel.hpp>
 
 namespace NetworKit {
 
