@@ -5,18 +5,17 @@
  *      Author: Kolja Esders (kolja.esders@student.kit.edu)
  */
 
-#include "NeighborhoodUtility.h"
-#include "../auxiliary/Parallel.h"
+#include <networkit/linkprediction/NeighborhoodUtility.hpp>
 
 namespace NetworKit {
 
 std::pair<std::vector<node>, std::vector<node>> NeighborhoodUtility::getSortedNeighborhoods(const Graph& G, node u, node v) {
-  std::vector<node> uNeighbors = G.neighbors(u);
-  std::vector<node> vNeighbors = G.neighbors(v);
+  std::vector<node> uNeighbors(G.neighborRange(u).begin(), G.neighborRange(u).end());
+  std::vector<node> vNeighbors(G.neighborRange(v).begin(), G.neighborRange(v).end());
   // We have no guarantee that the neighbor-vectors are sorted so we have to
   // sort them in order for set-functions to work properly.
-  Aux::Parallel::sort(uNeighbors.begin(), uNeighbors.end());
-  Aux::Parallel::sort(vNeighbors.begin(), vNeighbors.end());
+  std::sort(uNeighbors.begin(), uNeighbors.end());
+  std::sort(vNeighbors.begin(), vNeighbors.end());
   return std::make_pair(uNeighbors, vNeighbors);
 }
 
