@@ -5,8 +5,8 @@
  *      Author: Kolja Esders (kolja.esders@student.kit.edu)
  */
 
-#include "ResourceAllocationIndex.h"
-#include "NeighborhoodUtility.h"
+#include <networkit/linkprediction/ResourceAllocationIndex.hpp>
+#include <networkit/linkprediction/NeighborhoodUtility.hpp>
 
 namespace NetworKit {
 
