@@ -4,23 +4,22 @@
  *  Created on: 26.05.2018
  *      Author:  Hung Tran <htran@ae.cs.uni-frankfurt.de>, Manuel Penschuck <networkit@manuel.jetzt>
  */
+// networkit-format
 
-#include "../auxiliary/Random.h"
+#include <networkit/auxiliary/Random.hpp>
 
-#include "Curveball.h"
-#include "CurveballImpl.h"
+#include "CurveballImpl.hpp"
+#include <networkit/randomization/Curveball.hpp>
 
 namespace NetworKit {
 
-Curveball::Curveball(const Graph &G) :
-    impl(new CurveballDetails::CurveballIM{G})
-{}
+Curveball::Curveball(const Graph &G) : impl(new CurveballDetails::CurveballIM{G}) {}
 
 // We have to define a "default" destructor here, since the definition of
 // CurveballDetails::CurveballImpl is not known in the header file
 Curveball::~Curveball() = default;
 
-void Curveball::run(const CurveballDetails::trade_vector& trades) {
+void Curveball::run(const CurveballDetails::trade_vector &trades) {
     impl->run(trades);
 }
 
@@ -28,7 +27,7 @@ Graph Curveball::getGraph(bool parallel) {
     return impl->getGraph(parallel);
 }
 
-std::string Curveball::toString() const  {
+std::string Curveball::toString() const {
     return "Curveball";
 }
 
@@ -36,4 +35,4 @@ count Curveball::getNumberOfAffectedEdges() const {
     return impl->getNumberOfAffectedEdges();
 }
 
-}
+} // namespace NetworKit
