@@ -31,7 +31,7 @@ def extractLargestComponent(G):
 	cSizes = cc.getnk.componentsizes()
 	(largestCompo, size) = max(cSizes.items(), key=operator.itemgetter(1))
 	logging.info("extracting component {0} containing {1} nodes".format(largestCompo, size))
-	compoNodes = [v for v in G.nodes() if cc.componentOfNode(v) is largestCompo]
+	compoNodes = [v for v in G.iterNodes() if cc.componentOfNode(v) is largestCompo]
 	C = G.subgraphFromNodes(compoNodes)
 	return C
 
